@@ -7,14 +7,16 @@ describe("is working",{
     tab <- tbl_memdb(data.frame(x = 1:2), "w")
     m <- modifier(if (x > 1) x <- 1)
 
-    updates <- modifier_to_sql(m, tab)
-    working <- is_working_db(updates, tab)
+    # updates <- modifier_to_sql(m, tab)
+    working <- is_working_db(m, tab)
 
     expect_equal(working, TRUE)
   })
 
   it("is working check",{
-    tab <- tbl_memdb(data.frame(x = 1:2), "w2")
+
+    tab <- memdb_frame(x = 1:2)
+    df <- as.data.frame(tab)
 
     m <- modifier( if (x > 1) x <- 1
                  , if (x > 2) y <- 1
@@ -22,11 +24,11 @@ describe("is working",{
                  , if (x < 0) x <- 0
                  )
 
-    updates <- modifier_to_sql(m, tab)
     expect_warning({
-      working <- is_working_db(updates, tab)
+      working <- is_working_db(m, tab)
     })
 
-    expect_equal(working, c(TRUE, FALSE, FALSE, TRUE))
+    expect_equal(working, c(TRUE, TRUE, FALSE, TRUE))
+    expect_equal(as.data.frame(tab), df)
   })
 })
